@@ -1,34 +1,5 @@
-/*
- * Copyright 2018-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2018-2019, Intel Corporation */
 
 /*
  * vmemcache.c -- vmemcache implementation
@@ -120,7 +91,7 @@ vmemcache_set_size(VMEMcache *cache, size_t size)
 		return -1;
 	}
 
-	if (size >= (1ULL << 56)) {
+	if (size >= 1ULL << ((sizeof(void *) > 4) ? 56 : 31)) {
 		ERR("implausible large size %zu", size);
 		errno = EINVAL;
 		return -1;
@@ -573,6 +544,34 @@ get_index:
 	return (ssize_t)read;
 }
 
+/*
+ * vmemcache_exists -- checks, without side-effects, if a key exists
+ */
+int
+vmemcache_exists(VMEMcache *cache, const void *key, size_t key_size,
+	size_t *vsize)
+{
+	LOG(3, "cache %p key %p key_size %zu vsize %p",
+		cache, key, key_size, vsize);
+
+	struct cache_entry *entry;
+
+	int ret = vmcache_index_get(cache->index, key, key_size, &entry, 0);
+	if (ret < 0)
+		return -1;
+
+	if (entry == NULL)
+		return 0;
+
+	if (vsize)
+		*vsize = entry->value.vsize;
+
+	vmemcache_entry_release(cache, entry);
+
+	return 1;
+}
+
+
 /*
  * vmemcache_evict -- evict an element from the vmemcache
  */
