@@ -1,34 +1,5 @@
-/*
- * Copyright 2018-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2018-2019, Intel Corporation */
 
 /*
  * vmemcache_test_basic.c -- basic unit test for libvmemcache
@@ -385,11 +356,17 @@ test_put_get_evict(const char *dir, enum vmemcache_repl_p repl_p)
 	size_t vsize = 0; /* real size of the object */
 	ssize_t ret;
 
+	size_t exists_vsize;
+	ret = vmemcache_exists(cache, key, key_size, &exists_vsize);
+	UT_ASSERTeq(ret, 1);
+
 	/* get the only one element */
 	ret = vmemcache_get(cache, key, key_size, vbuf, vbufsize, 0, &vsize);
 	if (ret < 0)
 		UT_FATAL("vmemcache_get: %s", vmemcache_errormsg());
 
+	UT_ASSERTeq(exists_vsize, vsize);
+
 	if ((size_t)ret != val_size)
 		UT_FATAL(
 			"vmemcache_get: wrong return value: %zi (should be %zu)",
@@ -425,6 +402,9 @@ test_put_get_evict(const char *dir, enum vmemcache_repl_p repl_p)
 	if (ret != -1 || errno != ENOENT)
 		UT_FATAL("vmemcache_get did not return -1 (no such element)");
 
+	ret = vmemcache_exists(cache, key, key_size, NULL);
+	UT_ASSERTeq(ret, 0);
+
 	vmemcache_delete(cache);
 }
 
